@@ -1,4 +1,4 @@
-"""Galileo"""
+"""Galileo."""
 
 # flake8: noqa: F401
 # ruff: noqa: F401
@@ -29,4 +29,4 @@ from galileo_core.schemas.protect.response import Response
 from galileo_core.schemas.protect.ruleset import Ruleset
 from galileo_core.schemas.protect.stage import StageType
 
-__version__ = "1.26.0"
+__version__ = "1.28.0"
