@@ -1,7 +1,7 @@
 import json
 import logging
 import time
-from typing import Any, Optional
+from typing import Any, Callable, Optional
 from uuid import UUID
 
 from galileo.handlers.base_async_handler import GalileoAsyncBaseHandler
@@ -9,7 +9,9 @@ from galileo.handlers.langchain.handler import GalileoCallback
 from galileo.handlers.langchain.utils import get_agent_name, is_agent_node
 from galileo.logger import GalileoLogger
 from galileo.schema.handlers import NODE_TYPE
+from galileo.schema.trace import TracesIngestRequest
 from galileo.utils.serialization import EventSerializer, serialize_to_str
+from galileo.utils.uuid_utils import convert_uuid_if_uuid7
 
 _logger = logging.getLogger(__name__)
 
@@ -44,12 +46,14 @@ class GalileoAsyncCallback(AsyncCallbackHandler):
         galileo_logger: Optional[GalileoLogger] = None,
         start_new_trace: bool = True,
         flush_on_chain_end: bool = True,
+        ingestion_hook: Optional[Callable[[TracesIngestRequest], None]] = None,
     ):
         self._handler = GalileoAsyncBaseHandler(
             flush_on_chain_end=flush_on_chain_end,
             start_new_trace=start_new_trace,
             galileo_logger=galileo_logger,
             integration="langchain",
+            ingestion_hook=ingestion_hook,
         )
 
     async def on_chain_start(
@@ -67,6 +71,10 @@ class GalileoAsyncCallback(AsyncCallbackHandler):
         if tags and "langsmith:hidden" in tags:
             return
 
+        # Convert UUID7s to UUID4s if needed
+        run_id = convert_uuid_if_uuid7(run_id) or run_id
+        parent_run_id = convert_uuid_if_uuid7(parent_run_id) if parent_run_id else None
+
         node_type: NODE_TYPE = "chain"
         node_name = GalileoCallback._get_node_name(node_type, serialized, kwargs)
 
@@ -84,6 +92,9 @@ class GalileoAsyncCallback(AsyncCallbackHandler):
         self, outputs: dict[str, Any], *, run_id: UUID, parent_run_id: Optional[UUID] = None, **kwargs: Any
     ) -> Any:
         """Langchain callback when a chain ends."""
+        # Convert UUID7 to UUID4 if needed
+        run_id = convert_uuid_if_uuid7(run_id) or run_id
+
         # The input is sent via kwargs in on_chain_end in async streaming mode
         if "inputs" in kwargs:
             kwargs["input"] = serialize_to_str(kwargs["inputs"])
@@ -91,6 +102,8 @@ class GalileoAsyncCallback(AsyncCallbackHandler):
 
     async def on_agent_finish(self, finish: AgentFinish, *, run_id: UUID, **kwargs: Any) -> Any:
         """Langchain callback when an agent finishes."""
+        # Convert UUID7 to UUID4 if needed
+        run_id = convert_uuid_if_uuid7(run_id) or run_id
         await self._handler.async_end_node(run_id, output=serialize_to_str(finish))
 
     async def on_llm_start(
@@ -109,6 +122,10 @@ class GalileoAsyncCallback(AsyncCallbackHandler):
 
         Note: This callback is only used for non-chat models.
         """
+        # Convert UUID7s to UUID4s if needed
+        run_id = convert_uuid_if_uuid7(run_id) or run_id
+        parent_run_id = convert_uuid_if_uuid7(parent_run_id) if parent_run_id else None
+
         node_type: NODE_TYPE = "llm"
         node_name = GalileoCallback._get_node_name(node_type, serialized, kwargs)
         invocation_params = kwargs.get("invocation_params", {})
@@ -131,6 +148,9 @@ class GalileoAsyncCallback(AsyncCallbackHandler):
 
     async def on_llm_new_token(self, token: str, *, run_id: UUID, **kwargs: Any) -> Any:
         """Langchain callback when an LLM node generates a new token."""
+        # Convert UUID7 to UUID4 if needed
+        run_id = convert_uuid_if_uuid7(run_id) or run_id
+
         node = self._handler.get_node(run_id)
         if not node:
             return
@@ -152,6 +172,10 @@ class GalileoAsyncCallback(AsyncCallbackHandler):
         **kwargs: Any,
     ) -> Any:
         """Langchain callback when a chat model starts."""
+        # Convert UUID7s to UUID4s if needed
+        run_id = convert_uuid_if_uuid7(run_id) or run_id
+        parent_run_id = convert_uuid_if_uuid7(parent_run_id) if parent_run_id else None
+
         node_type: NODE_TYPE = "chat"
         node_name = GalileoCallback._get_node_name(node_type, serialized, kwargs)
         invocation_params = kwargs.get("invocation_params", {})
@@ -185,6 +209,9 @@ class GalileoAsyncCallback(AsyncCallbackHandler):
         self, response: LLMResult, *, run_id: UUID, parent_run_id: Optional[UUID] = None, **kwargs: Any
     ) -> Any:
         """Langchain callback when an LLM node ends."""
+        # Convert UUID7 to UUID4 if needed
+        run_id = convert_uuid_if_uuid7(run_id) or run_id
+
         token_usage = response.llm_output.get("token_usage", {}) if response.llm_output else {}
 
         try:
@@ -214,6 +241,10 @@ class GalileoAsyncCallback(AsyncCallbackHandler):
         **kwargs: Any,
     ) -> Any:
         """Langchain callback when a tool node starts."""
+        # Convert UUID7s to UUID4s if needed
+        run_id = convert_uuid_if_uuid7(run_id) or run_id
+        parent_run_id = convert_uuid_if_uuid7(parent_run_id) if parent_run_id else None
+
         node_type: NODE_TYPE = "tool"
         node_name = GalileoCallback._get_node_name(node_type, serialized, kwargs)
         if "inputs" in kwargs and isinstance(kwargs["inputs"], dict):
@@ -232,6 +263,9 @@ class GalileoAsyncCallback(AsyncCallbackHandler):
         self, output: Any, *, run_id: UUID, parent_run_id: Optional[UUID] = None, **kwargs: Any
     ) -> Any:
         """Langchain callback when a tool node ends."""
+        # Convert UUID7 to UUID4 if needed
+        run_id = convert_uuid_if_uuid7(run_id) or run_id
+
         end_node_kwargs = {}
         if (tool_message := GalileoCallback._find_tool_message(output)) is not None:
             end_node_kwargs["output"] = tool_message.content
@@ -259,6 +293,10 @@ class GalileoAsyncCallback(AsyncCallbackHandler):
         **kwargs: Any,
     ) -> Any:
         """Langchain callback when a retriever node starts."""
+        # Convert UUID7s to UUID4s if needed
+        run_id = convert_uuid_if_uuid7(run_id) or run_id
+        parent_run_id = convert_uuid_if_uuid7(parent_run_id) if parent_run_id else None
+
         node_type: NODE_TYPE = "retriever"
         node_name = GalileoCallback._get_node_name(node_type, serialized, kwargs)
         await self._handler.async_start_node(
@@ -275,6 +313,9 @@ class GalileoAsyncCallback(AsyncCallbackHandler):
         self, documents: list[Document], *, run_id: UUID, parent_run_id: Optional[UUID] = None, **kwargs: Any
     ) -> Any:
         """Langchain callback when a retriever node ends."""
+        # Convert UUID7 to UUID4 if needed
+        run_id = convert_uuid_if_uuid7(run_id) or run_id
+
         try:
             serialized_response = json.loads(json.dumps(documents, cls=EventSerializer))
         except Exception as e:
@@ -287,22 +328,30 @@ class GalileoAsyncCallback(AsyncCallbackHandler):
         self, error: Exception, *, run_id: UUID, parent_run_id: Optional[UUID] = None, **kwargs: Any
     ) -> Any:
         """Called when a chain errors."""
+        # Convert UUID7 to UUID4 if needed
+        run_id = convert_uuid_if_uuid7(run_id) or run_id
         await self._handler.async_end_node(run_id, output=f"Error: {error!s}")
 
     async def on_llm_error(
         self, error: Exception, *, run_id: UUID, parent_run_id: Optional[UUID] = None, **kwargs: Any
     ) -> Any:
         """Called when an LLM errors."""
+        # Convert UUID7 to UUID4 if needed
+        run_id = convert_uuid_if_uuid7(run_id) or run_id
         await self._handler.async_end_node(run_id, output=f"Error: {error!s}")
 
     async def on_tool_error(
         self, error: Exception, *, run_id: UUID, parent_run_id: Optional[UUID] = None, **kwargs: Any
     ) -> Any:
         """Called when a tool errors."""
+        # Convert UUID7 to UUID4 if needed
+        run_id = convert_uuid_if_uuid7(run_id) or run_id
         await self._handler.async_end_node(run_id, output=f"Error: {error!s}")
 
     async def on_retriever_error(
         self, error: Exception, *, run_id: UUID, parent_run_id: Optional[UUID] = None, **kwargs: Any
     ) -> Any:
         """Called when a retriever errors."""
+        # Convert UUID7 to UUID4 if needed
+        run_id = convert_uuid_if_uuid7(run_id) or run_id
         await self._handler.async_end_node(run_id, output=f"Error: {error!s}")
