@@ -61,20 +61,21 @@ def _build_response(
 def sync_detailed(
     scorer_id: str, *, client: ApiClient, body: BodyCreateCodeScorerVersionScorersScorerIdVersionCodePost
 ) -> Response[Union[BaseScorerVersionResponse, HTTPValidationError]]:
-    """Create Code Scorer Version
+    """Create Code Scorer Version.
 
     Args:
         scorer_id (str):
         body (BodyCreateCodeScorerVersionScorersScorerIdVersionCodePost):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[BaseScorerVersionResponse, HTTPValidationError]]
     """
-
     kwargs = _get_kwargs(scorer_id=scorer_id, body=body)
 
     response = client.request(**kwargs)
@@ -85,40 +86,42 @@ def sync_detailed(
 def sync(
     scorer_id: str, *, client: ApiClient, body: BodyCreateCodeScorerVersionScorersScorerIdVersionCodePost
 ) -> Optional[Union[BaseScorerVersionResponse, HTTPValidationError]]:
-    """Create Code Scorer Version
+    """Create Code Scorer Version.
 
     Args:
         scorer_id (str):
         body (BodyCreateCodeScorerVersionScorersScorerIdVersionCodePost):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[BaseScorerVersionResponse, HTTPValidationError]
     """
-
     return sync_detailed(scorer_id=scorer_id, client=client, body=body).parsed
 
 
 async def asyncio_detailed(
     scorer_id: str, *, client: ApiClient, body: BodyCreateCodeScorerVersionScorersScorerIdVersionCodePost
 ) -> Response[Union[BaseScorerVersionResponse, HTTPValidationError]]:
-    """Create Code Scorer Version
+    """Create Code Scorer Version.
 
     Args:
         scorer_id (str):
         body (BodyCreateCodeScorerVersionScorersScorerIdVersionCodePost):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[BaseScorerVersionResponse, HTTPValidationError]]
     """
-
     kwargs = _get_kwargs(scorer_id=scorer_id, body=body)
 
     response = await client.arequest(**kwargs)
@@ -129,18 +132,19 @@ async def asyncio_detailed(
 async def asyncio(
     scorer_id: str, *, client: ApiClient, body: BodyCreateCodeScorerVersionScorersScorerIdVersionCodePost
 ) -> Optional[Union[BaseScorerVersionResponse, HTTPValidationError]]:
-    """Create Code Scorer Version
+    """Create Code Scorer Version.
 
     Args:
         scorer_id (str):
         body (BodyCreateCodeScorerVersionScorersScorerIdVersionCodePost):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[BaseScorerVersionResponse, HTTPValidationError]
     """
-
     return (await asyncio_detailed(scorer_id=scorer_id, client=client, body=body)).parsed
