@@ -61,7 +61,7 @@ def _build_response(
 def sync_detailed(
     scorer_id: str, *, client: ApiClient, body: CreateScorerVersionRequest
 ) -> Response[Union[BaseScorerVersionResponse, HTTPValidationError]]:
-    """Create Preset Scorer Version
+    """Create Preset Scorer Version.
 
      Create a preset scorer version.
 
@@ -69,14 +69,15 @@ def sync_detailed(
         scorer_id (str):
         body (CreateScorerVersionRequest):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[BaseScorerVersionResponse, HTTPValidationError]]
     """
-
     kwargs = _get_kwargs(scorer_id=scorer_id, body=body)
 
     response = client.request(**kwargs)
@@ -87,7 +88,7 @@ def sync_detailed(
 def sync(
     scorer_id: str, *, client: ApiClient, body: CreateScorerVersionRequest
 ) -> Optional[Union[BaseScorerVersionResponse, HTTPValidationError]]:
-    """Create Preset Scorer Version
+    """Create Preset Scorer Version.
 
      Create a preset scorer version.
 
@@ -95,21 +96,22 @@ def sync(
         scorer_id (str):
         body (CreateScorerVersionRequest):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[BaseScorerVersionResponse, HTTPValidationError]
     """
-
     return sync_detailed(scorer_id=scorer_id, client=client, body=body).parsed
 
 
 async def asyncio_detailed(
     scorer_id: str, *, client: ApiClient, body: CreateScorerVersionRequest
 ) -> Response[Union[BaseScorerVersionResponse, HTTPValidationError]]:
-    """Create Preset Scorer Version
+    """Create Preset Scorer Version.
 
      Create a preset scorer version.
 
@@ -117,14 +119,15 @@ async def asyncio_detailed(
         scorer_id (str):
         body (CreateScorerVersionRequest):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[BaseScorerVersionResponse, HTTPValidationError]]
     """
-
     kwargs = _get_kwargs(scorer_id=scorer_id, body=body)
 
     response = await client.arequest(**kwargs)
@@ -135,7 +138,7 @@ async def asyncio_detailed(
 async def asyncio(
     scorer_id: str, *, client: ApiClient, body: CreateScorerVersionRequest
 ) -> Optional[Union[BaseScorerVersionResponse, HTTPValidationError]]:
-    """Create Preset Scorer Version
+    """Create Preset Scorer Version.
 
      Create a preset scorer version.
 
@@ -143,12 +146,13 @@ async def asyncio(
         scorer_id (str):
         body (CreateScorerVersionRequest):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[BaseScorerVersionResponse, HTTPValidationError]
     """
-
     return (await asyncio_detailed(scorer_id=scorer_id, client=client, body=body)).parsed
