@@ -84,7 +84,7 @@ def sync_detailed(
     starting_token: Union[Unset, int] = 0,
     limit: Union[Unset, int] = 100,
 ) -> Response[Union[HTTPValidationError, ListDatasetResponse]]:
-    """List Datasets
+    """List Datasets.
 
     Args:
         actions (Union[Unset, list[DatasetAction]]): Actions to include in the 'permissions'
@@ -92,14 +92,15 @@ def sync_detailed(
         starting_token (Union[Unset, int]):  Default: 0.
         limit (Union[Unset, int]):  Default: 100.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[HTTPValidationError, ListDatasetResponse]]
     """
-
     kwargs = _get_kwargs(actions=actions, starting_token=starting_token, limit=limit)
 
     response = client.request(**kwargs)
@@ -114,7 +115,7 @@ def sync(
     starting_token: Union[Unset, int] = 0,
     limit: Union[Unset, int] = 100,
 ) -> Optional[Union[HTTPValidationError, ListDatasetResponse]]:
-    """List Datasets
+    """List Datasets.
 
     Args:
         actions (Union[Unset, list[DatasetAction]]): Actions to include in the 'permissions'
@@ -122,14 +123,15 @@ def sync(
         starting_token (Union[Unset, int]):  Default: 0.
         limit (Union[Unset, int]):  Default: 100.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[HTTPValidationError, ListDatasetResponse]
     """
-
     return sync_detailed(client=client, actions=actions, starting_token=starting_token, limit=limit).parsed
 
 
@@ -140,7 +142,7 @@ async def asyncio_detailed(
     starting_token: Union[Unset, int] = 0,
     limit: Union[Unset, int] = 100,
 ) -> Response[Union[HTTPValidationError, ListDatasetResponse]]:
-    """List Datasets
+    """List Datasets.
 
     Args:
         actions (Union[Unset, list[DatasetAction]]): Actions to include in the 'permissions'
@@ -148,14 +150,15 @@ async def asyncio_detailed(
         starting_token (Union[Unset, int]):  Default: 0.
         limit (Union[Unset, int]):  Default: 100.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[HTTPValidationError, ListDatasetResponse]]
     """
-
     kwargs = _get_kwargs(actions=actions, starting_token=starting_token, limit=limit)
 
     response = await client.arequest(**kwargs)
@@ -170,7 +173,7 @@ async def asyncio(
     starting_token: Union[Unset, int] = 0,
     limit: Union[Unset, int] = 100,
 ) -> Optional[Union[HTTPValidationError, ListDatasetResponse]]:
-    """List Datasets
+    """List Datasets.
 
     Args:
         actions (Union[Unset, list[DatasetAction]]): Actions to include in the 'permissions'
@@ -178,12 +181,13 @@ async def asyncio(
         starting_token (Union[Unset, int]):  Default: 0.
         limit (Union[Unset, int]):  Default: 100.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[HTTPValidationError, ListDatasetResponse]
     """
-
     return (await asyncio_detailed(client=client, actions=actions, starting_token=starting_token, limit=limit)).parsed
