@@ -42,16 +42,17 @@ def _build_response(*, client: ApiClient, response: httpx.Response) -> Response[
 
 
 def sync_detailed(*, client: ApiClient) -> Response[HealthcheckResponse]:
-    """Healthcheck
+    """Healthcheck.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[HealthcheckResponse]
     """
-
     kwargs = _get_kwargs()
 
     response = client.request(**kwargs)
@@ -60,30 +61,32 @@ def sync_detailed(*, client: ApiClient) -> Response[HealthcheckResponse]:
 
 
 def sync(*, client: ApiClient) -> Optional[HealthcheckResponse]:
-    """Healthcheck
+    """Healthcheck.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         HealthcheckResponse
     """
-
     return sync_detailed(client=client).parsed
 
 
 async def asyncio_detailed(*, client: ApiClient) -> Response[HealthcheckResponse]:
-    """Healthcheck
+    """Healthcheck.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[HealthcheckResponse]
     """
-
     kwargs = _get_kwargs()
 
     response = await client.arequest(**kwargs)
@@ -92,14 +95,15 @@ async def asyncio_detailed(*, client: ApiClient) -> Response[HealthcheckResponse
 
 
 async def asyncio(*, client: ApiClient) -> Optional[HealthcheckResponse]:
-    """Healthcheck
+    """Healthcheck.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         HealthcheckResponse
     """
-
     return (await asyncio_detailed(client=client)).parsed
