@@ -57,21 +57,22 @@ def _build_response(
 def sync_detailed(
     *, client: ApiClient, body: ProjectCreate
 ) -> Response[Union[HTTPValidationError, ProjectCreateResponse]]:
-    """Create Project
+    """Create Project.
 
      Create a new project.
 
     Args:
         body (ProjectCreate):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[HTTPValidationError, ProjectCreateResponse]]
     """
-
     kwargs = _get_kwargs(body=body)
 
     response = client.request(**kwargs)
@@ -80,42 +81,44 @@ def sync_detailed(
 
 
 def sync(*, client: ApiClient, body: ProjectCreate) -> Optional[Union[HTTPValidationError, ProjectCreateResponse]]:
-    """Create Project
+    """Create Project.
 
      Create a new project.
 
     Args:
         body (ProjectCreate):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[HTTPValidationError, ProjectCreateResponse]
     """
-
     return sync_detailed(client=client, body=body).parsed
 
 
 async def asyncio_detailed(
     *, client: ApiClient, body: ProjectCreate
 ) -> Response[Union[HTTPValidationError, ProjectCreateResponse]]:
-    """Create Project
+    """Create Project.
 
      Create a new project.
 
     Args:
         body (ProjectCreate):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[HTTPValidationError, ProjectCreateResponse]]
     """
-
     kwargs = _get_kwargs(body=body)
 
     response = await client.arequest(**kwargs)
@@ -126,19 +129,20 @@ async def asyncio_detailed(
 async def asyncio(
     *, client: ApiClient, body: ProjectCreate
 ) -> Optional[Union[HTTPValidationError, ProjectCreateResponse]]:
-    """Create Project
+    """Create Project.
 
      Create a new project.
 
     Args:
         body (ProjectCreate):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[HTTPValidationError, ProjectCreateResponse]
     """
-
     return (await asyncio_detailed(client=client, body=body)).parsed
