@@ -56,20 +56,21 @@ def _build_response(*, client: ApiClient, response: httpx.Response) -> Response[
 def sync_detailed(
     project_id: str, *, client: ApiClient, body: BodyUploadFileProjectsProjectIdUploadFilePost
 ) -> Response[Union[Any, HTTPValidationError]]:
-    """Upload File
+    """Upload File.
 
     Args:
         project_id (str):
         body (BodyUploadFileProjectsProjectIdUploadFilePost):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[Any, HTTPValidationError]]
     """
-
     kwargs = _get_kwargs(project_id=project_id, body=body)
 
     response = client.request(**kwargs)
@@ -80,40 +81,42 @@ def sync_detailed(
 def sync(
     project_id: str, *, client: ApiClient, body: BodyUploadFileProjectsProjectIdUploadFilePost
 ) -> Optional[Union[Any, HTTPValidationError]]:
-    """Upload File
+    """Upload File.
 
     Args:
         project_id (str):
         body (BodyUploadFileProjectsProjectIdUploadFilePost):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[Any, HTTPValidationError]
     """
-
     return sync_detailed(project_id=project_id, client=client, body=body).parsed
 
 
 async def asyncio_detailed(
     project_id: str, *, client: ApiClient, body: BodyUploadFileProjectsProjectIdUploadFilePost
 ) -> Response[Union[Any, HTTPValidationError]]:
-    """Upload File
+    """Upload File.
 
     Args:
         project_id (str):
         body (BodyUploadFileProjectsProjectIdUploadFilePost):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[Any, HTTPValidationError]]
     """
-
     kwargs = _get_kwargs(project_id=project_id, body=body)
 
     response = await client.arequest(**kwargs)
@@ -124,18 +127,19 @@ async def asyncio_detailed(
 async def asyncio(
     project_id: str, *, client: ApiClient, body: BodyUploadFileProjectsProjectIdUploadFilePost
 ) -> Optional[Union[Any, HTTPValidationError]]:
-    """Upload File
+    """Upload File.
 
     Args:
         project_id (str):
         body (BodyUploadFileProjectsProjectIdUploadFilePost):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[Any, HTTPValidationError]
     """
-
     return (await asyncio_detailed(project_id=project_id, client=client, body=body)).parsed
