@@ -61,7 +61,7 @@ def _build_response(
 def sync_detailed(
     project_id: str, template_id: str, *, client: ApiClient, body: BasePromptTemplateVersion
 ) -> Response[Union[BasePromptTemplateVersionResponse, HTTPValidationError]]:
-    """Create Prompt Template Version
+    """Create Prompt Template Version.
 
      Create a prompt template version for a given prompt template.
 
@@ -88,14 +88,15 @@ def sync_detailed(
         template_id (str):
         body (BasePromptTemplateVersion):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[BasePromptTemplateVersionResponse, HTTPValidationError]]
     """
-
     kwargs = _get_kwargs(project_id=project_id, template_id=template_id, body=body)
 
     response = client.request(**kwargs)
@@ -106,7 +107,7 @@ def sync_detailed(
 def sync(
     project_id: str, template_id: str, *, client: ApiClient, body: BasePromptTemplateVersion
 ) -> Optional[Union[BasePromptTemplateVersionResponse, HTTPValidationError]]:
-    """Create Prompt Template Version
+    """Create Prompt Template Version.
 
      Create a prompt template version for a given prompt template.
 
@@ -133,21 +134,22 @@ def sync(
         template_id (str):
         body (BasePromptTemplateVersion):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[BasePromptTemplateVersionResponse, HTTPValidationError]
     """
-
     return sync_detailed(project_id=project_id, template_id=template_id, client=client, body=body).parsed
 
 
 async def asyncio_detailed(
     project_id: str, template_id: str, *, client: ApiClient, body: BasePromptTemplateVersion
 ) -> Response[Union[BasePromptTemplateVersionResponse, HTTPValidationError]]:
-    """Create Prompt Template Version
+    """Create Prompt Template Version.
 
      Create a prompt template version for a given prompt template.
 
@@ -174,14 +176,15 @@ async def asyncio_detailed(
         template_id (str):
         body (BasePromptTemplateVersion):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[BasePromptTemplateVersionResponse, HTTPValidationError]]
     """
-
     kwargs = _get_kwargs(project_id=project_id, template_id=template_id, body=body)
 
     response = await client.arequest(**kwargs)
@@ -192,7 +195,7 @@ async def asyncio_detailed(
 async def asyncio(
     project_id: str, template_id: str, *, client: ApiClient, body: BasePromptTemplateVersion
 ) -> Optional[Union[BasePromptTemplateVersionResponse, HTTPValidationError]]:
-    """Create Prompt Template Version
+    """Create Prompt Template Version.
 
      Create a prompt template version for a given prompt template.
 
@@ -219,12 +222,13 @@ async def asyncio(
         template_id (str):
         body (BasePromptTemplateVersion):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[BasePromptTemplateVersionResponse, HTTPValidationError]
     """
-
     return (await asyncio_detailed(project_id=project_id, template_id=template_id, client=client, body=body)).parsed
