@@ -54,7 +54,7 @@ def _build_response(
 
 
 def sync_detailed(template_id: str, *, client: ApiClient) -> Response[Union[DeletePromptResponse, HTTPValidationError]]:
-    """Delete Global Template
+    """Delete Global Template.
 
      Delete a global prompt template given a template ID.
 
@@ -73,14 +73,15 @@ def sync_detailed(template_id: str, *, client: ApiClient) -> Response[Union[Dele
     Args:
         template_id (str):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[DeletePromptResponse, HTTPValidationError]]
     """
-
     kwargs = _get_kwargs(template_id=template_id)
 
     response = client.request(**kwargs)
@@ -89,7 +90,7 @@ def sync_detailed(template_id: str, *, client: ApiClient) -> Response[Union[Dele
 
 
 def sync(template_id: str, *, client: ApiClient) -> Optional[Union[DeletePromptResponse, HTTPValidationError]]:
-    """Delete Global Template
+    """Delete Global Template.
 
      Delete a global prompt template given a template ID.
 
@@ -108,21 +109,22 @@ def sync(template_id: str, *, client: ApiClient) -> Optional[Union[DeletePromptR
     Args:
         template_id (str):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[DeletePromptResponse, HTTPValidationError]
     """
-
     return sync_detailed(template_id=template_id, client=client).parsed
 
 
 async def asyncio_detailed(
     template_id: str, *, client: ApiClient
 ) -> Response[Union[DeletePromptResponse, HTTPValidationError]]:
-    """Delete Global Template
+    """Delete Global Template.
 
      Delete a global prompt template given a template ID.
 
@@ -141,14 +143,15 @@ async def asyncio_detailed(
     Args:
         template_id (str):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[DeletePromptResponse, HTTPValidationError]]
     """
-
     kwargs = _get_kwargs(template_id=template_id)
 
     response = await client.arequest(**kwargs)
@@ -157,7 +160,7 @@ async def asyncio_detailed(
 
 
 async def asyncio(template_id: str, *, client: ApiClient) -> Optional[Union[DeletePromptResponse, HTTPValidationError]]:
-    """Delete Global Template
+    """Delete Global Template.
 
      Delete a global prompt template given a template ID.
 
@@ -176,12 +179,13 @@ async def asyncio(template_id: str, *, client: ApiClient) -> Optional[Union[Dele
     Args:
         template_id (str):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[DeletePromptResponse, HTTPValidationError]
     """
-
     return (await asyncio_detailed(template_id=template_id, client=client)).parsed
