@@ -71,19 +71,20 @@ def _build_response(
 def sync_detailed(
     *, client: ApiClient, body: ProtectRequest
 ) -> Response[Union[HTTPValidationError, Union["InvokeResponse", "ProtectResponse"]]]:
-    """Invoke
+    """Invoke.
 
     Args:
         body (ProtectRequest): Protect request schema with custom OpenAPI title.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[HTTPValidationError, Union['InvokeResponse', 'ProtectResponse']]]
     """
-
     kwargs = _get_kwargs(body=body)
 
     response = client.request(**kwargs)
@@ -94,38 +95,40 @@ def sync_detailed(
 def sync(
     *, client: ApiClient, body: ProtectRequest
 ) -> Optional[Union[HTTPValidationError, Union["InvokeResponse", "ProtectResponse"]]]:
-    """Invoke
+    """Invoke.
 
     Args:
         body (ProtectRequest): Protect request schema with custom OpenAPI title.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[HTTPValidationError, Union['InvokeResponse', 'ProtectResponse']]
     """
-
     return sync_detailed(client=client, body=body).parsed
 
 
 async def asyncio_detailed(
     *, client: ApiClient, body: ProtectRequest
 ) -> Response[Union[HTTPValidationError, Union["InvokeResponse", "ProtectResponse"]]]:
-    """Invoke
+    """Invoke.
 
     Args:
         body (ProtectRequest): Protect request schema with custom OpenAPI title.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[HTTPValidationError, Union['InvokeResponse', 'ProtectResponse']]]
     """
-
     kwargs = _get_kwargs(body=body)
 
     response = await client.arequest(**kwargs)
@@ -136,17 +139,18 @@ async def asyncio_detailed(
 async def asyncio(
     *, client: ApiClient, body: ProtectRequest
 ) -> Optional[Union[HTTPValidationError, Union["InvokeResponse", "ProtectResponse"]]]:
-    """Invoke
+    """Invoke.
 
     Args:
         body (ProtectRequest): Protect request schema with custom OpenAPI title.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[HTTPValidationError, Union['InvokeResponse', 'ProtectResponse']]
     """
-
     return (await asyncio_detailed(client=client, body=body)).parsed
