@@ -61,21 +61,22 @@ def _build_response(
 def sync_detailed(
     project_id: str, run_id: str, *, client: ApiClient, body: RunScorerSettingsPatchRequest
 ) -> Response[Union[HTTPValidationError, RunScorerSettingsResponse]]:
-    """Upsert Scorers Config
+    """Upsert Scorers Config.
 
     Args:
         project_id (str):
         run_id (str):
         body (RunScorerSettingsPatchRequest):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[HTTPValidationError, RunScorerSettingsResponse]]
     """
-
     kwargs = _get_kwargs(project_id=project_id, run_id=run_id, body=body)
 
     response = client.request(**kwargs)
@@ -86,42 +87,44 @@ def sync_detailed(
 def sync(
     project_id: str, run_id: str, *, client: ApiClient, body: RunScorerSettingsPatchRequest
 ) -> Optional[Union[HTTPValidationError, RunScorerSettingsResponse]]:
-    """Upsert Scorers Config
+    """Upsert Scorers Config.
 
     Args:
         project_id (str):
         run_id (str):
         body (RunScorerSettingsPatchRequest):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[HTTPValidationError, RunScorerSettingsResponse]
     """
-
     return sync_detailed(project_id=project_id, run_id=run_id, client=client, body=body).parsed
 
 
 async def asyncio_detailed(
     project_id: str, run_id: str, *, client: ApiClient, body: RunScorerSettingsPatchRequest
 ) -> Response[Union[HTTPValidationError, RunScorerSettingsResponse]]:
-    """Upsert Scorers Config
+    """Upsert Scorers Config.
 
     Args:
         project_id (str):
         run_id (str):
         body (RunScorerSettingsPatchRequest):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[HTTPValidationError, RunScorerSettingsResponse]]
     """
-
     kwargs = _get_kwargs(project_id=project_id, run_id=run_id, body=body)
 
     response = await client.arequest(**kwargs)
@@ -132,19 +135,20 @@ async def asyncio_detailed(
 async def asyncio(
     project_id: str, run_id: str, *, client: ApiClient, body: RunScorerSettingsPatchRequest
 ) -> Optional[Union[HTTPValidationError, RunScorerSettingsResponse]]:
-    """Upsert Scorers Config
+    """Upsert Scorers Config.
 
     Args:
         project_id (str):
         run_id (str):
         body (RunScorerSettingsPatchRequest):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[HTTPValidationError, RunScorerSettingsResponse]
     """
-
     return (await asyncio_detailed(project_id=project_id, run_id=run_id, client=client, body=body)).parsed
