@@ -61,20 +61,21 @@ def _build_response(
 def sync_detailed(
     project_id: str, *, client: ApiClient, body: LogRecordsAvailableColumnsRequest
 ) -> Response[Union[HTTPValidationError, LogRecordsAvailableColumnsResponse]]:
-    """Spans Available Columns
+    """Spans Available Columns.
 
     Args:
         project_id (str):
         body (LogRecordsAvailableColumnsRequest):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[HTTPValidationError, LogRecordsAvailableColumnsResponse]]
     """
-
     kwargs = _get_kwargs(project_id=project_id, body=body)
 
     response = client.request(**kwargs)
@@ -85,40 +86,42 @@ def sync_detailed(
 def sync(
     project_id: str, *, client: ApiClient, body: LogRecordsAvailableColumnsRequest
 ) -> Optional[Union[HTTPValidationError, LogRecordsAvailableColumnsResponse]]:
-    """Spans Available Columns
+    """Spans Available Columns.
 
     Args:
         project_id (str):
         body (LogRecordsAvailableColumnsRequest):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[HTTPValidationError, LogRecordsAvailableColumnsResponse]
     """
-
     return sync_detailed(project_id=project_id, client=client, body=body).parsed
 
 
 async def asyncio_detailed(
     project_id: str, *, client: ApiClient, body: LogRecordsAvailableColumnsRequest
 ) -> Response[Union[HTTPValidationError, LogRecordsAvailableColumnsResponse]]:
-    """Spans Available Columns
+    """Spans Available Columns.
 
     Args:
         project_id (str):
         body (LogRecordsAvailableColumnsRequest):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[HTTPValidationError, LogRecordsAvailableColumnsResponse]]
     """
-
     kwargs = _get_kwargs(project_id=project_id, body=body)
 
     response = await client.arequest(**kwargs)
@@ -129,18 +132,19 @@ async def asyncio_detailed(
 async def asyncio(
     project_id: str, *, client: ApiClient, body: LogRecordsAvailableColumnsRequest
 ) -> Optional[Union[HTTPValidationError, LogRecordsAvailableColumnsResponse]]:
-    """Spans Available Columns
+    """Spans Available Columns.
 
     Args:
         project_id (str):
         body (LogRecordsAvailableColumnsRequest):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[HTTPValidationError, LogRecordsAvailableColumnsResponse]
     """
-
     return (await asyncio_detailed(project_id=project_id, client=client, body=body)).parsed
