@@ -23,7 +23,8 @@ T = TypeVar("T", bound="ExtendedSessionRecord")
 @_attrs_define
 class ExtendedSessionRecord:
     """
-    Attributes:
+    Attributes
+    ----------
         id (str): Galileo ID of the session
         project_id (str): Galileo ID of the project associated with this trace or span
         run_id (str): Galileo ID of the run (log stream or experiment) associated with this trace or span
