@@ -31,7 +31,8 @@ T = TypeVar("T", bound="ExtendedToolSpanRecordWithChildren")
 @_attrs_define
 class ExtendedToolSpanRecordWithChildren:
     """
-    Attributes:
+    Attributes
+    ----------
         id (str): Galileo ID of the session, trace or span
         parent_id (str): Galileo ID of the parent of this span
         project_id (str): Galileo ID of the project associated with this trace or span
