@@ -16,7 +16,8 @@ T = TypeVar("T", bound="HTTPValidationError")
 @_attrs_define
 class HTTPValidationError:
     """
-    Attributes:
+    Attributes
+    ----------
         detail (Union[Unset, list['ValidationError']]):
     """
 
