@@ -22,7 +22,8 @@ T = TypeVar("T", bound="LlmSpan")
 @_attrs_define
 class LlmSpan:
     """
-    Attributes:
+    Attributes
+    ----------
         created_at (Union[Unset, datetime.datetime]): Timestamp of the trace or span's creation.
         dataset_input (Union[None, Unset, str]): Input to the dataset associated with this trace
         dataset_metadata (Union[Unset, LlmSpanDatasetMetadata]): Metadata from the dataset associated with this trace
