@@ -13,7 +13,8 @@ T = TypeVar("T", bound="ProjectCreatorFilter")
 @_attrs_define
 class ProjectCreatorFilter:
     """
-    Attributes:
+    Attributes
+    ----------
         value (Union[list[str], str]):
         name (Union[Literal['creator'], Unset]):  Default: 'creator'.
         operator (Union[Unset, ProjectCreatorFilterOperator]):  Default: ProjectCreatorFilterOperator.EQ.
