@@ -10,7 +10,8 @@ T = TypeVar("T", bound="StringData")
 @_attrs_define
 class StringData:
     """
-    Attributes:
+    Attributes
+    ----------
         input_strings (list[str]):
     """
 
